@@ -125,16 +125,16 @@ def croshell(
             pass
     if visidata:
         if file_obj.suffix == ".json":
-            fire_line = f"uv run --with visidata vd {str(file_obj)}"
+            fire_line = f"uv run --python 3.14 --with visidata vd {str(file_obj)}"
         else:
-            fire_line = f"uv run --with visidata,pyarrow vd {str(file_obj)}"
+            fire_line = f"uv run --python 3.14 --with visidata,pyarrow vd {str(file_obj)}"
     elif marimo:
         if Path.home().joinpath("code/machineconfig").exists(): requirements = f"""--with marimo --project "{str(Path.home().joinpath("code/machineconfig"))}" """
-        else: requirements = """--with "marimo,machineconfig[plot]>=6.57" """
+        else: requirements = """--python 3.14 --with "marimo,machineconfig[plot]>=6.57" """
         fire_line = f"""
 cd {str(pyfile.parent)}
-uv run --with "marimo" marimo convert {pyfile.name} -o marimo_nb.py
-uv run  {requirements} marimo edit --host 0.0.0.0 marimo_nb.py
+uv run --python 3.14 --with "marimo" marimo convert {pyfile.name} -o marimo_nb.py
+uv run {requirements} marimo edit --host 0.0.0.0 marimo_nb.py
 """
     elif jupyter:
         if Path.home().joinpath("code/machineconfig").exists(): requirements = f"""--project "{str(Path.home().joinpath("code/machineconfig"))}" --with jupyterlab """
@@ -153,7 +153,7 @@ code --new-window {str(pyfile)}
         if interpreter == "ipython": profile = f" --profile {ipython_profile} --no-banner"
         else: profile = ""
         if Path.home().joinpath("code/machineconfig").exists(): ve_line = f"""--project "{str(Path.home().joinpath("code/machineconfig"))}" """
-        else: ve_line = """--with "machineconfig[plot]>=6.57" """
+        else: ve_line = """--python 3.14 --with "machineconfig[plot]>=6.57" """
         # ve_path_maybe, ipython_profile_maybe = get_ve_path_and_ipython_profile(Path.cwd())
         # --python 3.14
         fire_line = f"uv run {ve_line} {interpreter} {interactivity} {profile} {str(pyfile)}"
